@@ -4,10 +4,13 @@ import re
 import os.path
 import urllib
 import zipfile
+import shutil
+
 from django.core.management.base import AppCommand, CommandError
 from django.conf import settings
 #import ast
 from stubtools.core import StubRootCommand
+import stubtools
 
 class Command(StubRootCommand):
     help = 'sets-up folder structure for django files and directories if missing from a given project.'
@@ -58,6 +61,10 @@ class Command(StubRootCommand):
         if result == "y":
             self.getTwitterBootstrap()
 
+        result = self.checkInput("Do you want to create a Base html template file?")
+        if result == "y":
+            self.addBaseHtmlFile()
+
     def splitConfigSetup(self):
         '''
         This sets up the split config that works really well for deployments.  It seperates
@@ -97,33 +104,7 @@ class Command(StubRootCommand):
         dev_settings_file = os.path.join(settings_dir, "dev.py")
         if not os.path.exists(dev_settings_file):
             FILE = open(dev_settings_file, 'w')
-
-            lines = ["from base import *"]
-
-            lines.append("\n# DATABASES = {")
-            lines.append("#     'default': {")
-            lines.append("#         'ENGINE': 'django.db.backends.sqlite3', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.")
-            lines.append("#         'NAME': 'database.sqlite',                      # Or path to database file if using sqlite3.")
-            lines.append("#         'USER': '',                      # Not used with sqlite3.")
-            lines.append("#         'PASSWORD': '',                  # Not used with sqlite3.")
-            lines.append("#         'HOST': '',                      # Set to empty string for localhost. Not used with sqlite3.")
-            lines.append("#         'PORT': '',                      # Set to empty string for default. Not used with sqlite3.")
-            lines.append("#     }")
-            lines.append("# }")
-
-            lines.append("\nDEV_ONLY_APPS = (")
-            lines.append("#     'debug_toolbar',")
-            lines.append(")")
-
-            lines.append("\nINSTALLED_APPS = DEV_ONLY_APPS + INSTALLED_APPS")
-            lines.append("\n# MIDDLEWARE_CLASSES += ('debug_toolbar.middleware.DebugToolbarMiddleware',)")
-            lines.append("\n# INTERNAL_IPS = ('127.0.0.1',)")
-
-            lines.append("\nDEBUG_TOOLBAR_CONFIG = {")
-            lines.append("    'INTERCEPT_REDIRECTS': False,")
-            lines.append("    'SHOW_TEMPLATE_CONTEXT': True,")
-            lines.append("}\n\n")
-
+            lines = self.loadTemplateLines( os.path.join(stubtools.__path__[0], "templates", "dev_py.txt") )
             FILE.writelines("\n".join(lines))
             FILE.close()
 
@@ -131,64 +112,22 @@ class Command(StubRootCommand):
         dev_settings_file = os.path.join(settings_dir, "production.py")
         if not os.path.exists(dev_settings_file):
             FILE = open(dev_settings_file, 'w')
-
-            # COULD USE TO MOVE THIS TO A TEMPLATE FILE FOR EASIER MAINTINACE
-
-            lines = ["from base import *"]
-
-            lines.append("\n# DATABASES = {")
-            lines.append("#     'default': {")
-            lines.append("#         'ENGINE': 'django.db.backends.sqlite3', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.")
-            lines.append("#         'NAME': 'database.sqlite',                      # Or path to database file if using sqlite3.")
-            lines.append("#         'USER': '',                      # Not used with sqlite3.")
-            lines.append("#         'PASSWORD': '',                  # Not used with sqlite3.")
-            lines.append("#         'HOST': '',                      # Set to empty string for localhost. Not used with sqlite3.")
-            lines.append("#         'PORT': '',                      # Set to empty string for default. Not used with sqlite3.")
-            lines.append("#     }")
-            lines.append("# }")
-
-            lines.append("\nPRODUCTION_ONLY_APPS = (")
-            lines.append(")")
-
-            lines.append("\nINSTALLED_APPS = PRODUCTION_ONLY_APPS + INSTALLED_APPS")
-
-            lines.append("\n########## STORAGE CONFIGURATION")
-            lines.append("# INSTALLED_APPS += ('storages', )")
-            lines.append("\n# DEFAULT_FILE_STORAGE = 'storages.backends.s3boto.S3BotoStorage'")
-            lines.append("# STATICFILES_STORAGE = 'storages.backends.s3boto.S3BotoStorage'")
-            lines.append("\n# AWS_QUERYSTRING_AUTH = False")
-            lines.append("\n# AWS_HEADERS = {")
-            lines.append("#     'Expires': 'Thu, 15 Apr 2020 20:00:00 GMT',")
-            lines.append("#     'Cache-Control': 'max-age=86400',")
-            lines.append("# }")
-            lines.append("\n# #Boto requires subdomain formatting.")
-            lines.append("# from S3 import CallingFormat")
-            lines.append("# AWS_CALLING_FORMAT = CallingFormat.SUBDOMAIN")
-            lines.append("\n# Amazon S3 configuration.")
-            lines.append("# if 'AWS_ACCESS_KEY_ID' in os.environ:")
-            lines.append("#     AWS_ACCESS_KEY_ID = os.environ['AWS_ACCESS_KEY_ID']")
-            lines.append("# else:")
-            lines.append("#     raise Exception('Missing AWS_ACCESS_KEY_ID')")
-            lines.append("\n# if 'AWS_SECRET_ACCESS_KEY' in os.environ:")
-            lines.append("#     AWS_SECRET_ACCESS_KEY = os.environ['AWS_SECRET_ACCESS_KEY']")
-            lines.append("# else:")
-            lines.append("#     raise Exception('Missing AWS_SECRET_ACCESS_KEY')")
-            lines.append("\n# AWS_STORAGE_BUCKET_NAME = 'bevlog'")
-            lines.append("\n# STATIC_URL = 'https://s3.amazonaws.com/bevlog/'")
-            lines.append("# MEDIA_URL = STATIC_URL")
-            lines.append("########## END STORAGE CONFIGURATION\n\n")
-
+            lines = self.loadTemplateLines( os.path.join(stubtools.__path__[0], "templates", "production_py.txt") )
             FILE.writelines("\n".join(lines))
             FILE.close()
 
+    def loadTemplateLines(self, path):
+            SRC = open(path, 'r')
+            lines = SRC.readlines()
+            SRC.close()
+            return lines
+
     def templatePathSetup(self):
         print "\nCHECKING FOR TEMPLATE PATH"
 
         if not len(settings.TEMPLATE_DIRS):
             print "\tERROR: NO TEMPLATE FILE DIRECOTRIES FOUND!\n\tAdd something like this to your config:\n"
-            print "TEMPLATE_DIRS = ("
-            print "\tos.path.join(PROJECT_PATH, 'templates'),"
-            print ")\n"
+            print "TEMPLATE_DIRS = (\n    os.path.join(PROJECT_PATH, 'templates'),\n)\n"
             return
 
         for directory in settings.TEMPLATE_DIRS:
@@ -203,9 +142,7 @@ class Command(StubRootCommand):
 
         if not len(settings.STATICFILES_DIRS):
             print "\tERROR: NO STATIC FILE DIRECOTRIES FOUND!\n\tAdd something like this to your config:\n"
-            print "STATICFILES_DIRS = ("
-            print "\tos.path.join(PROJECT_PATH, 'static'),"
-            print ")\n"
+            print "STATICFILES_DIRS = (\n    os.path.join(PROJECT_PATH, 'static'),\n)\n"
             return
 
         if len(settings.STATICFILES_DIRS) == 1:
@@ -264,13 +201,18 @@ class Command(StubRootCommand):
             os.rename(os.path.join(bsdir, item), os.path.join(staticdir, item))
 
         # NEED TO ADD CLEANUP OF tmp DIRECTORIES
-        # cleanup_list.reverse()
-        # for item in cleanup_list:
-        #     os.remove(item)
-        # os.remove(tmpdir)
+        shutil.rmtree(tmpdir)
 
+    def addBaseHtmlFile(self):
+        pass
         # SETUP THE base.html FILE
 
+        base_html_file = os.path.join(settings.TEMPLATE_DIRS[0], "base.html")
+        if not os.path.exists(base_html_file):
+            FILE = open(base_html_file, 'w')
+            lines = self.loadTemplateLines( os.path.join(stubtools.__path__[0], "templates", "base_html.txt") )
+            FILE.writelines("\n".join(lines))
+            FILE.close()
 
 
 
